#!/usr/bin/env node
'use strict';

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _download = require('../utils/download');

var _download2 = _interopRequireDefault(_download);

var _writer = require('../utils/writer');

var _writer2 = _interopRequireDefault(_writer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var argv = _yargs2.default.options({
  projectId: {
    alias: 'p',
    demandOption: true,
    type: 'string'
  },
  version: {
    alias: 'v',
    demandOption: true,
    type: 'string'
  },
  scope: {
    alias: 's',
    type: 'string',
    default: 'patch',
    choices: ['major', 'minor', 'patch']
  },
  locale: {
    alias: 'l',
    type: 'string',
    default: 'en-US',
    describe: 'Locale of the release notes include in the generated output file. Does not apply to the "json" format.'
  },
  format: {
    alias: 'f',
    default: 'md',
    type: 'string',
    choices: ['md', 'json']
  },
  outFile: {
    alias: 'o',
    type: 'string',
    demandOption: true,
    describe: 'output file to save release notes content'
  },
  help: {
    alias: 'h'
  }
}).help('h').argv;

(0, _download2.default)(argv.projectId, argv.version, argv.scope).then(function (releaseNotes) {
  if (Array.isArray(releaseNotes) && releaseNotes.length > 0) {
    return (0, _writer2.default)(releaseNotes, argv.locale, argv.format, argv.outFile);
  } else {
    console.log('No release notes found.');
  }
}).catch(function (error) {
  console.error(error);
});