'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getReleaseNotes = getReleaseNotes;

var _download = require('./utils/download');

var _download2 = _interopRequireDefault(_download);

var _json = require('./utils/formatters/json');

var _json2 = _interopRequireDefault(_json);

var _markdown = require('./utils/formatters/markdown');

var _markdown2 = _interopRequireDefault(_markdown);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {
  getReleaseNotes: getReleaseNotes,
  toJson: _json2.default,
  toMarkdown: _markdown2.default
};
function getReleaseNotes(projectId, version, options) {
  try {
    var opts = verifyOptions(options);
    return (0, _download2.default)(projectId, version, opts.scope).then(function (releaseNotes) {
      switch (opts.format.toLowerCase()) {
        case 'json':
          return (0, _json2.default)(releaseNotes);

        case 'md':
          return (0, _markdown2.default)(releaseNotes, opts.locale);

        default:
          throw new Error('Unsupported format: ' + opts.format);
      }
    });
  } catch (e) {
    return Promise.reject(e);
  }
}

function verifyOptions(options) {
  var opts = Object.assign({}, options);

  if (!opts.scope) {
    opts.scope = 'patch';
  }

  if (!opts.locale) {
    opts.locale = 'en-US';
  }

  if (!opts.format) {
    options.format = 'md';
  }

  return opts;
}