'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = download;

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function download(projectId, version, scope) {
  return new Promise(function (resolve, reject) {
    var url = 'http://releases.gatewayapps.com/api/projects/' + projectId + '/notes?version=' + version + '&scope=' + scope;
    _http2.default.get(url, function (res) {
      var statusCode = res.statusCode;
      var contentType = res.headers['content-type'];

      var error = void 0;

      if (statusCode !== 200) {
        error = new Error('Request Failed.\nStatus Code: ' + statusCode);
      } else if (!/^application\/json/.test(contentType)) {
        error = new Error('Invalid content-type.\nExpected application/json but received ' + contentType);
      }
      if (error) {
        reject(error);
        // consume response data to free up memory
        res.resume();
        return;
      }

      res.setEncoding('utf8');
      var rawData = '';
      res.on('data', function (chunk) {
        rawData += chunk;
      });
      res.on('end', function () {
        try {
          var response = JSON.parse(rawData);

          if (response.success === true) {
            resolve(response.versions);
            return;
          } else {
            reject(new Error('Failed to get release notes: ' + response.message));
            return;
          }
        } catch (e) {
          reject(e);
        }
      });
    }).on('error', function (e) {
      reject(e);
    });
  });
}