'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = toMarkdown;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function toMarkdown(releaseNotes) {
  var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en-US';

  if (!Array.isArray(releaseNotes) || releaseNotes.length === 0) {
    return;
  }

  var content = [];
  var releaseCount = releaseNotes.length;

  releaseNotes.forEach(function (rn) {
    var notes = rn.notes.filter(function (n) {
      return n.locale.toLowerCase() === locale.toLowerCase();
    });
    if (notes.length === 0) {
      return;
    }

    var note = notes[0];

    if (!Array.isArray(note.items) && !note.items.length > 0) {
      return;
    }

    if (releaseCount > 1) {
      var releaseHeader = '## ' + rn.version;
      if (rn.name) {
        releaseHeader += ': ' + rn.name;
      }
      content.push(releaseHeader);
    }

    if (note.header) {
      content.push(note.header);
      content.push('');
    }

    note.items.forEach(function (item) {
      var itemNote = '- ';
      if (Array.isArray(item.tags) && item.tags.length > 0) {
        itemNote += '**' + item.tags.map(function (t) {
          return _lodash2.default.startCase(t);
        }).join(' / ') + '** - ';
      }
      itemNote += item.description.replace(/^(\s*)-/gm, '$1  -');
      content.push(itemNote);
    });
    content.push('');
  });

  return content.join('\n');
}